<?xml version="1.0" encoding="ISO-8859-1" ?>
<xsl:stylesheet xmlns:xsl="http://www.w3.org/1999/XSL/Transform" version="1.0">
	<xsl:output method="html" version="4.0" encoding="ISO-8859-1"/>

	<xsl:template match="Document">	
		<div class="contentitem">
			<h1><xsl:value-of select="module/name"/></h1>
			<xsl:apply-templates select="UpdateUser"/>
			<xsl:apply-templates select="UserNotFoundInDB"/>
		</div>
	</xsl:template>
	
	<xsl:template match="UserNotFoundInDB">
	
		<p><xsl:value-of select="$UserNotFoundInDB.errorMessage"/></p>
	
	</xsl:template>
	
	<xsl:template match="UpdateUser">		
		
		<xsl:apply-templates select="validationException/validationError"/>
		
		<xsl:if test="UserUpdated">
			<p><xsl:value-of select="$UpdateUser.userUpdatedMessage"/></p>
		</xsl:if>
		
		<form method="POST" action="{/document/requestinfo/uri}" name="userform">
			<table>
				<tr>
					<td><xsl:value-of select="$UpdateUser.username"/>:</td>
					<td>
						<input type="text" name="username" size="40">
							<xsl:if test="changeUsername='false'">
								<xsl:attribute name="readonly">true</xsl:attribute>							
							</xsl:if>
							
							<xsl:attribute name="value">
								<xsl:choose>
									<xsl:when test="requestparameters">
										<xsl:value-of select="requestparameters/parameter[name='username']/value"/>
									</xsl:when>
									<xsl:otherwise>
										<xsl:value-of select="user/username"/>
									</xsl:otherwise>
								</xsl:choose>
							</xsl:attribute>
						</input>
					</td>
				</tr>
				<xsl:if test="changePassword='true'">
					<tr>
						<td>
							<input type="checkbox" onclick="document.userform.password.disabled=!this.checked">
								<xsl:if test="requestparameters/parameter[name='password']">
									<xsl:attribute name="checked"/>							
								</xsl:if>	
							</input>
							<xsl:value-of select="$UpdateUser.changePassword"/>:
						</td>
						<td>
							<input type="password" name="password" value="" size="40">
								<xsl:if test="not(requestparameters/parameter[name='password'])">
									<xsl:attribute name="disabled">true</xsl:attribute>							
								</xsl:if>									
							</input>
						</td>
					</tr>						
				</xsl:if>				
				<tr>
					<td><xsl:value-of select="$UpdateUser.firstname"/>:</td>
					<td>
						<input type="text" name="firstname" size="40">
							<xsl:if test="changeFirstname='false'">
								<xsl:attribute name="readonly">true</xsl:attribute>							
							</xsl:if>						
						
							<xsl:attribute name="value">
								<xsl:choose>
									<xsl:when test="requestparameters">
										<xsl:value-of select="requestparameters/parameter[name='firstname']/value"/>
									</xsl:when>
									<xsl:otherwise>
										<xsl:value-of select="user/firstname"/>
									</xsl:otherwise>
								</xsl:choose>
							</xsl:attribute>
						</input>
					</td>
				</tr>
				<tr>
					<td><xsl:value-of select="$UpdateUser.lastname"/>:</td>
					<td>
						<input type="text" name="lastname" size="40">
							<xsl:if test="changeLastname='false'">
								<xsl:attribute name="readonly">true</xsl:attribute>							
							</xsl:if>						
						
							<xsl:attribute name="value">
								<xsl:choose>
									<xsl:when test="requestparameters">
										<xsl:value-of select="requestparameters/parameter[name='lastname']/value"/>
									</xsl:when>
									<xsl:otherwise>
										<xsl:value-of select="user/lastname"/>
									</xsl:otherwise>
								</xsl:choose>
							</xsl:attribute>
						</input>
					</td>
				</tr>
				<tr>
					<td><xsl:value-of select="$UpdateUser.email"/>:</td>
					<td>
						<input type="text" name="email" size="40">
							<xsl:if test="changeEmail='false'">
								<xsl:attribute name="readonly">true</xsl:attribute>							
							</xsl:if>						
						
							<xsl:attribute name="value">
								<xsl:choose>
									<xsl:when test="requestparameters">
										<xsl:value-of select="requestparameters/parameter[name='email']/value"/>
									</xsl:when>
									<xsl:otherwise>
										<xsl:value-of select="user/email"/>
									</xsl:otherwise>
								</xsl:choose>
							</xsl:attribute>
						</input>
					</td>
				</tr>
				<tr>
					<td><xsl:value-of select="$UpdateUser.groups"/>:</td>
					<td>
						<xsl:choose>
							<xsl:when test="user/groups">
								<xsl:apply-templates select="user/groups/group"/>
							</xsl:when>
							<xsl:otherwise>
								<xsl:value-of select="$UpdateUser.none"/>
							</xsl:otherwise>
						</xsl:choose>
					</td>
				</tr>
				<xsl:if test="user/admin='true'">
					<tr>
						<td><xsl:value-of select="$UpdateUser.admin"/>:</td>
						<td><xsl:value-of select="$UpdateUser.yes"/></td>
					</tr>		
				</xsl:if>							
			</table>
			
			<br/>
			
			<table>
				<tr>
					<td><xsl:value-of select="$UpdateUser.accountCreated"/>:</td>
					<td><xsl:value-of select="user/added"/></td>
				</tr>
				<tr>
					<td><xsl:value-of select="$UpdateUser.lastLogin"/>:</td>
					<td><xsl:value-of select="user/lastLogin"/></td>
				</tr>				
			</table>
			
			<br/>
			
			<div align="right">
				<input type="submit" value="{$UpdateUser.saveChanges}"/>			
			</div>
		</form>
	</xsl:template>	
	
	<xsl:template match="group">
		<xsl:value-of select="name"/><br/>
	</xsl:template>
	
	<xsl:template match="validationError">
		<xsl:if test="fieldName and validationErrorType and not(messageKey)">
			<p class="error">
				<xsl:choose>
					<xsl:when test="validationErrorType='RequiredField'">
						<xsl:value-of select="$UpdateUser.RequiredField"/><xsl:text>:</xsl:text>
					</xsl:when>
					<xsl:when test="validationErrorType='InvalidFormat'">
						<xsl:value-of select="$UpdateUser.InvalidFormat"/><xsl:text>:</xsl:text>
					</xsl:when>		
					<xsl:otherwise>
						<xsl:value-of select="$UpdateUser.unknownFieldError"/><xsl:text>:</xsl:text>
					</xsl:otherwise>
				</xsl:choose>
				
				<xsl:text>&#x20;</xsl:text>
				
				<xsl:choose>
					<xsl:when test="fieldName = 'firstname'">
						<xsl:value-of select="$UpdateUser.firstname"/><xsl:text>!</xsl:text>
					</xsl:when>
					<xsl:when test="fieldName = 'lastname'">
						<xsl:value-of select="$UpdateUser.lastname"/><xsl:text>!</xsl:text>
					</xsl:when>	
					<xsl:when test="fieldName = 'username'">
						<xsl:value-of select="$UpdateUser.username"/><xsl:text>!</xsl:text>
					</xsl:when>
					<xsl:when test="fieldName = 'password'">
						<xsl:value-of select="$UpdateUser.password"/><xsl:text>!</xsl:text>
					</xsl:when>																
					<xsl:when test="fieldName = 'email'">
						<xsl:value-of select="$UpdateUser.email"/><xsl:text>!</xsl:text>
					</xsl:when>																																						
					<xsl:otherwise>
						<xsl:value-of select="fieldName"/><xsl:text>!</xsl:text>
					</xsl:otherwise>
				</xsl:choose>			
			</p>
		</xsl:if>
		
		<xsl:if test="messageKey">
			<p class="error">
				<xsl:choose>
					<xsl:when test="messageKey='UsernameAlreadyTaken'">
						<xsl:text><xsl:value-of select="$UpdateUser.usernameAlreadyTaken"/></xsl:text>
					</xsl:when>											
					<xsl:otherwise>
						<xsl:text><xsl:value-of select="$UpdateUser.unknownFault"/></xsl:text>
					</xsl:otherwise>
				</xsl:choose>
			</p>
		</xsl:if>
	</xsl:template>				
</xsl:stylesheet>